==> ispconfig3_billing_addon_1.2.zip: billing/interface/web/billing/list/invoice_message_template.list.php <==
<?php

/*
Copyright (c) 2010, Till Brehm, projektfarm Gmbh
All rights reserved.
*/

/*
	Datatypes:
	- INTEGER
	- DOUBLE
	- CURRENCY
	- VARCHAR
	- TEXT
	- DATE
*/



// Name of the list
$liste["name"] 				= "invoice_message_template";

// Database table
$liste["table"] 			= "invoice_message_template";

// Index index field of the database table
$liste["table_idx"]			= "invoice_message_template_id";

// Search Field Prefix
$liste["search_prefix"] 	= "search_";

// Records per page
$liste["records_per_page"] 	= 15;

// Script File of the list
$liste["file"]				= "invoice_message_template_list.php";

// Script file of the edit form
$liste["edit_file"]			= "invoice_message_template_edit.php";

// Script File of the delete script
$liste["delete_file"]		= "invoice_message_template_del.php";

// Paging Template
$liste["paging_tpl"]		= "templates/paging.tpl.htm";

// Enable authe
$liste["auth"]				= "yes";


/*****************************************************
* Suchfelder
*****************************************************/

$liste["item"][] = array(	'field'		=> "template_type",
							'datatype'	=> "VARCHAR",
							'formtype'	=> "SELECT",
							'op'		=> "=",
							'prefix'	=> "",
							'suffix'	=> "",
							'width'		=> "",
							'value'		=> array('invoice' => 'Invoice', 'refund' => 'Refund', 'reminder' => 'Reminder','other' => 'Other'));

$liste["item"][] = array(	'field'		=> "template_name",
							'datatype'	=> "VARCHAR",
							'formtype'	=> "TEXT",
							'op'		=> "like",
							'prefix'	=> "%",
							'suffix'	=> "%",
							'width'		=> "",
							'value'		=> "");





?>

==> ispconfig3_billing_addon_1.3.zip: billing/interface/web/billing/list/invoice_message_template.list.php <==
<?php

/*
Copyright (c) 2010, Till Brehm, projektfarm Gmbh
All rights reserved.
*/

/*
	Datatypes:
	- INTEGER
	- DOUBLE
	- CURRENCY
	- VARCHAR
	- TEXT
	- DATE
*/



// Name of the list
$liste["name"] 				= "invoice_message_template";

// Database table
$liste["table"] 			= "invoice_message_template";

// Index index field of the database table
$liste["table_idx"]			= "invoice_message_template_id";

// Search Field Prefix
$liste["search_prefix"] 	= "search_";

// Records per page
$liste["records_per_page"] 	= 15;

// Script File of the list
$liste["file"]				= "invoice_message_template_list.php";

// Script file of the edit form
$liste["edit_file"]			= "invoice_message_template_edit.php";

// Script File of the delete script
$liste["delete_file"]		= "invoice_message_template_del.php";

// Paging Template
$liste["paging_tpl"]		= "templates/paging.tpl.htm";

// Enable authe
$liste["auth"]				= "yes";


/*****************************************************
* Suchfelder
*****************************************************/

$liste["item"][] = array(	'field'		=> "template_type",
							'datatype'	=> "VARCHAR",
							'formtype'	=> "SELECT",
							'op'		=> "=",
							'prefix'	=> "",
							'suffix'	=> "",
							'width'		=> "",
							'value'		=> array('invoice' => 'Invoice', 'refund' => 'Refund', 'reminder' => 'Reminder','chargeback' => 'Chargeback','other' => 'Other'));

$liste["item"][] = array(	'field'		=> "template_name",
							'datatype'	=> "VARCHAR",
							'formtype'	=> "TEXT",
							'op'		=> "like",
							'prefix'	=> "%",
							'suffix'	=> "%",
							'width'		=> "",
							'value'		=> "");





?>
